kMaxDepth top-level constant
int
const kMaxDepth
Maximum depth for nested objects to prevent infinite recursion
Implementation
const int kMaxDepth = 100;
Maximum depth for nested objects to prevent infinite recursion
const int kMaxDepth = 100;