ToonDecodingError class
Error that occurs during TOON decoding/parsing
- Inheritance
- Implementers
Constructors
Properties
- actualValue → String?
-
The actual value that was encountered
final
- column → int?
-
Column number where the error occurred (1-based)
finalinherited
-
context
→ Map<
String, dynamic> ? -
Additional context about the error
finalinherited
- expectedType → Type?
-
The expected type that failed to parse
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- line → int?
-
Line number where the error occurred (1-based)
finalinherited
- location → String
-
Get location information as a formatted string
no setterinherited
- message → String
-
Error message describing what went wrong
finalinherited
- offset → int?
-
Character offset where the error occurred (0-based)
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → ToonErrorSeverity
-
Severity level of the error
finalinherited
- source → String?
-
Source text where the error occurred
finalinherited
- sourceExcerpt → String?
-
Get the source excerpt around the error location
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited